@@ -19,7 +19,7 @@ package MongoDB::BulkWriteView;
 # ABSTRACT: Bulk write operations against a query document
 
 use version;
-our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.6'; # TRIAL
 
 use Moo;
 
@@ -38,7 +38,7 @@ use namespace::clean -except => 'meta';
 has _query => (
     is       => 'ro',
     isa      => IxHash,
-    coerce   => 1,
+    coerce   => IxHash->coercion,
     required => 1
 );
 
@@ -148,7 +148,7 @@ MongoDB::BulkWriteView - Bulk write operations against a query document
 
 =head1 VERSION
 
-version v0.999.999.5
+version v0.999.999.6
 
 =head1 SYNOPSIS
 
