@@ -20,7 +20,7 @@ package MongoDB::Collection;
 # ABSTRACT: A MongoDB Collection
 
 use version;
-our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.6'; # TRIAL
 
 use MongoDB::Error;
 use MongoDB::IndexView;
@@ -99,7 +99,7 @@ has read_preference => (
     is       => 'ro',
     isa      => ReadPreference,
     required => 1,
-    coerce   => 1,
+    coerce   => ReadPreference->coercion,
 );
 
 #pod =attr write_concern
@@ -114,7 +114,7 @@ has write_concern => (
     is       => 'ro',
     isa      => WriteConcern,
     required => 1,
-    coerce   => 1,
+    coerce   => WriteConcern->coercion,
 );
 
 #pod =attr max_time_ms
@@ -145,7 +145,7 @@ has max_time_ms => (
 has bson_codec => (
     is       => 'ro',
     isa      => BSONCodec,
-    coerce   => 1,
+    coerce   => BSONCodec->coercion,
     required => 1,
 );
 
@@ -1715,7 +1715,7 @@ MongoDB::Collection - A MongoDB Collection
 
 =head1 VERSION
 
-version v0.999.999.5
+version v0.999.999.6
 
 =head1 SYNOPSIS
 
