@@ -20,7 +20,7 @@ package MongoDB::Database;
 # ABSTRACT: A MongoDB Database
 
 use version;
-our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.6'; # TRIAL
 
 use MongoDB::CommandResult;
 use MongoDB::Error;
@@ -75,7 +75,7 @@ has read_preference => (
     is       => 'ro',
     isa      => ReadPreference,
     required => 1,
-    coerce   => 1,
+    coerce   => ReadPreference->coercion,
 );
 
 #pod =attr write_concern
@@ -90,7 +90,7 @@ has write_concern => (
     is       => 'ro',
     isa      => WriteConcern,
     required => 1,
-    coerce   => 1,
+    coerce   => WriteConcern->coercion,
 );
 
 #pod =attr max_time_ms
@@ -121,7 +121,7 @@ has max_time_ms => (
 has bson_codec => (
     is       => 'ro',
     isa      => BSONCodec,
-    coerce   => 1,
+    coerce   => BSONCodec->coercion,
     required => 1,
 );
 
@@ -407,7 +407,7 @@ MongoDB::Database - A MongoDB Database
 
 =head1 VERSION
 
-version v0.999.999.5
+version v0.999.999.6
 
 =head1 SYNOPSIS
 
