@@ -20,7 +20,7 @@ package MongoDB::GridFS;
 # ABSTRACT: A file storage utility
 
 use version;
-our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.6'; # TRIAL
 
 use MongoDB::GridFS::File;
 use Digest::MD5;
@@ -66,7 +66,7 @@ has read_preference => (
     is       => 'ro',
     isa      => ReadPreference,
     required => 1,
-    coerce   => 1,
+    coerce   => ReadPreference->coercion,
 );
 
 #pod =attr write_concern
@@ -81,7 +81,7 @@ has write_concern => (
     is       => 'ro',
     isa      => WriteConcern,
     required => 1,
-    coerce   => 1,
+    coerce   => WriteConcern->coercion,
 );
 
 #pod =attr max_time_ms
@@ -112,7 +112,7 @@ has max_time_ms => (
 has bson_codec => (
     is       => 'ro',
     isa      => BSONCodec,
-    coerce   => 1,
+    coerce   => BSONCodec->coercion,
     required => 1,
 );
 
@@ -476,7 +476,7 @@ MongoDB::GridFS - A file storage utility
 
 =head1 VERSION
 
-version v0.999.999.5
+version v0.999.999.6
 
 =head1 SYNOPSIS
 
