@@ -19,7 +19,7 @@ package MongoDB::MongoClient;
 # ABSTRACT: A connection to a MongoDB server or multi-server deployment
 
 use version;
-our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.6'; # TRIAL
 
 use Moo;
 use MongoDB;
@@ -179,7 +179,7 @@ sub _build_auth_mechanism_properties {
 has bson_codec => (
     is      => 'lazy',
     isa     => BSONCodec,
-    coerce  => 1,
+    coerce  => BSONCodec->coercion,
     writer  => '_set_bson_codec',
     builder => '_build_bson_codec',
 );
@@ -438,7 +438,7 @@ has port => (
 has read_pref_mode => (
     is      => 'lazy',
     isa     => ReadPrefMode,
-    coerce  => 1,
+    coerce  => ReadPrefMode->coercion,
     builder => '_build_read_pref_mode',
 );
 
@@ -475,7 +475,7 @@ sub _build_read_pref_mode {
 has read_pref_tag_sets => (
     is      => 'lazy',
     isa     => ArrayOfHashRef,
-    coerce  => 1,
+    coerce  => ArrayOfHashRef->coercion,
     builder => '_build_read_pref_tag_sets',
 );
 
@@ -1499,7 +1499,7 @@ MongoDB::MongoClient - A connection to a MongoDB server or multi-server deployme
 
 =head1 VERSION
 
-version v0.999.999.5
+version v0.999.999.6
 
 =head1 SYNOPSIS
 
@@ -2477,7 +2477,7 @@ C<auth_mechanism_properties> attribute or in the connection string.
 
     auth_mechanism_properties => { SERVICE_NAME => 'other_service' }
 
-    mongodb://.../?authMechanism=GSSAPI&authMechanism.SERVICE_NAME=other_service
+    mongodb://.../?authMechanism=GSSAPI&authMechanismProperties=SERVICE_NAME:other_service
 
 =head1 THREAD-SAFETY AND FORK-SAFETY
 
