@@ -19,7 +19,7 @@ package MongoDB::QueryResult::Filtered;
 # ABSTRACT: An iterator for Mongo query results with client-side filtering
 
 use version;
-our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.6'; # TRIAL
 
 use Moo;
 use Types::Standard qw(
@@ -38,7 +38,7 @@ has _post_filter => (
 
 sub has_next {
     my ($self) = @_;
-    my $limit = $self->limit;
+    my $limit = $self->_limit;
     if ( $limit > 0 && ( $self->cursor_at + 1 ) > $limit ) {
         $self->_kill_cursor;
         return 0;
@@ -73,7 +73,7 @@ MongoDB::QueryResult::Filtered - An iterator for Mongo query results with client
 
 =head1 VERSION
 
-version v0.999.999.5
+version v0.999.999.6
 
 =for Pod::Coverage has_next
 
