@@ -19,7 +19,7 @@ package MongoDB::ReadPreference;
 # ABSTRACT: Encapsulate and validate read preferences
 
 use version;
-our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.6'; # TRIAL
 
 use Moo;
 use MongoDB::Error;
@@ -52,7 +52,7 @@ has mode => (
     is      => 'ro',
     isa     => ReadPrefMode,
     default => 'primary',
-    coerce  => 1,
+    coerce  => ReadPrefMode->coercion,
 );
 
 #pod =attr tag_sets
@@ -69,7 +69,7 @@ has tag_sets => (
     is      => 'ro',
     isa     => ArrayOfHashRef,
     default => sub { [ {} ] },
-    coerce  => 1,
+    coerce  => ArrayOfHashRef->coercion,
 );
 
 sub BUILD {
@@ -131,7 +131,7 @@ MongoDB::ReadPreference - Encapsulate and validate read preferences
 
 =head1 VERSION
 
-version v0.999.999.5
+version v0.999.999.6
 
 =head1 SYNOPSIS
 
