@@ -19,7 +19,7 @@ package MongoDB::WriteConcern;
 # ABSTRACT: Encapsulate and validate a write concern
 
 use version;
-our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.6'; # TRIAL
 
 use Moo;
 use MongoDB::Error;
@@ -75,7 +75,7 @@ has wtimeout => (
 has j => (
     is        => 'ro',
     isa       => Booleanpm,
-    coerce    => 1,
+    coerce    => Booleanpm->coercion,
     predicate => '_has_j',
 );
 
@@ -101,9 +101,9 @@ sub _build_is_acknowledged {
 sub _build_as_struct {
     my ($self) = @_;
     return {
-        ( $self->_has_w        ? ( w        => $self->w )        : () ),
-        ( $self->_has_wtimeout ? ( wtimeout => $self->wtimeout ) : () ),
-        ( $self->_has_j        ? ( j        => $self->j )        : () ),
+        ( $self->_has_w        ? ( w        => $self->w )           : () ),
+        ( $self->_has_wtimeout ? ( wtimeout => 0+ $self->wtimeout ) : () ),
+        ( $self->_has_j        ? ( j        => $self->j )           : () ),
     };
 }
 
@@ -136,7 +136,7 @@ MongoDB::WriteConcern - Encapsulate and validate a write concern
 
 =head1 VERSION
 
-version v0.999.999.5
+version v0.999.999.6
 
 =head1 SYNOPSIS
 
